.. _bedreiging:

BEDREIGING OP HET LEVEN
#######################

| 285.1 Bedreiging met enig misdrijf tegen het leven gericht wordt gestraft met gevangenisstraf van ten hoogste twee jaren of geldboete van de vierde categorie.

2.3. Voor een veroordeling ter zake van bedreiging met enig misdrijf tegen het leven gericht is in een geval als het onderhavige vereist dat
     de bedreiging  van dien aard is en onder zodanige omstandigheden is geschied dat bij de bedreigde in redelijkheid de vrees kon ontstaan
     dat hij het leven zou kunnen verliezen (vgl. HR 7 juni 2005, ECLI:NL:HR:2005:AT3659, NJ 2005/448) en dat het opzet van de verdachte 
     daarop was gericht (vgl. HR 17 januari 1984, ECLI:NL:HR:1984:AC8252, NJ 1984/479).

